@@ -255,10 +255,6 @@ class Context {
 
             return controller.enqueue(decodedFrame);
         }
-
-        // TODO: this just passes through to the decoder. Is that ok? If we don't know the key yet
-        // we might want to buffer a bit but it is still unclear how to do that (and for how long etc).
-        controller.enqueue(encodedFrame);
     }
 
     /**
@@ -317,9 +313,11 @@ class Context {
             newUint8.set(new Uint8Array(plainText), frameHeader.byteLength);
 
             encodedFrame.data = newData;
+
+            return encodedFrame;
         } catch (error) {
             if (this._sharedKey) {
-                return encodedFrame;
+                return;
             }
 
             if (ratchetCount < RATCHET_WINDOW_SIZE) {
@@ -348,8 +346,6 @@ class Context {
 
             // TODO: notify the application about error status.
         }
-
-        return encodedFrame;
     }
 
 
